==> urbantrips-0.2.1.tar.gz: urbantrips-0.2.1/README.md <==
[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=EL-BID_UrbanTrips&metric=alert_status)](https://sonarcloud.io/summary/new_code?id=EL-BID_UrbanTrips)

![analytics image (flat)](https://raw.githubusercontent.com/vitr/google-analytics-beacon/master/static/badge-flat.gif)

![analytics](https://www.google-analytics.com/collect?v=1&cid=555&t=pageview&ec=repo&ea=open&dp=/urbantrips/readme&dt=&tid=UA-4677001-16)

![logo](https://github.com/EL-BID/UrbanTrips/blob/dev/docs/img/logo_readme.png)

# README

UrbanTrips es una biblioteca de código abierto que toma información de un sistema de pago con tarjeta inteligente de transporte público, infiere destinos de las etapas, construye cadenas de viaje para cada usuario y produce matrices de origen-destino y otros indicadores operativos. El principal objetivo de la librería es producir insumos útiles para la gestión del transporte público a partir de requerimientos mínimos de información y pre-procesamiento. Con sólo una tabla geolocalizada de transacciones proveniente de un sistema de pago electrónico, se podrán generar resultados, que serán más precisos cuanta más información adicional se incorpore al proceso a través de los archivos opcionales. El proceso elabora las matrices, los indicadores y construye una serie de gráficos y mapas útiles para la planificación y fiscalización del transporte público.

Para mayor información de la librería, instalación, configuración y uso puede leerse la [Documentación](https://el-bid.github.io/UrbanTrips/)

Para una discusión metodológica de cómo se imputan destinos y se construye la matriz de origen y destino se puede consultar este ![documento metodológico](https://github.com/EL-BID/UrbanTrips/blob/dev/docs/Metodologia_UrbanTrips.pdf "Documento metodológico").


## Agradecimientos

Queremos agradecer la colaboración de los gobiernos de Ciudad de Buenos Aires, Córdoba, Mendoza y Bariloche que proveyeron datos y participaron de valiosas conversaciones para mejorar esta librería.

## Licencia

Copyright© 2023. Banco Interamericano de Desarrollo ("BID"). Uso autorizado. [AM-331-A3](/LICENSE.md)


## Autores

Felipe González ([@alephcero](https://github.com/alephcero/)) 
Sebastián Anapolsky([@sanapolsky](https://github.com/sanapolsky/))

==> urbantrips-0.3.0.tar.gz: urbantrips-0.3.0/README.md <==
![analytics image (flat)](https://raw.githubusercontent.com/vitr/google-analytics-beacon/master/static/badge-flat.gif)

![analytics](https://www.google-analytics.com/collect?v=1&cid=555&t=pageview&ec=repo&ea=open&dp=/urbantrips/readme&dt=&tid=UA-4677001-16)

![logo](https://github.com/EL-BID/UrbanTrips/blob/dev/docs/img/logo_readme.png)

# README

UrbanTrips es una biblioteca de código abierto que toma información de un sistema de pago con tarjeta inteligente de transporte público, infiere destinos de las etapas, construye cadenas de viaje para cada usuario y produce matrices de origen-destino y otros indicadores operativos. El principal objetivo de la librería es producir insumos útiles para la gestión del transporte público a partir de requerimientos mínimos de información y pre-procesamiento. Con sólo una tabla geolocalizada de transacciones proveniente de un sistema de pago electrónico, se podrán generar resultados, que serán más precisos cuanta más información adicional se incorpore al proceso a través de los archivos opcionales. El proceso elabora las matrices, los indicadores y construye una serie de gráficos y mapas útiles para la planificación y fiscalización del transporte público.

Para mayor información de la librería, instalación, configuración y uso puede leerse la [Documentación](https://el-bid.github.io/UrbanTrips/)

Para una discusión metodológica de cómo se imputan destinos y se construye la matriz de origen y destino se puede consultar este [documento metodológico](https://github.com/EL-BID/UrbanTrips/blob/dev/docs/Metodologia_UrbanTrips.pdf "Documento metodológico").


## Agradecimientos

Queremos agradecer la colaboración de los gobiernos de Ciudad de Buenos Aires, Córdoba, Mendoza y Bariloche que proveyeron datos y participaron de valiosas conversaciones para mejorar esta librería.

## Licencia

Copyright© 2023. Banco Interamericano de Desarrollo ("BID"). Uso autorizado. [AM-331-A3](/LICENSE.md)


## Autores

Felipe González ([@alephcero](https://github.com/alephcero/)) 
Sebastián Anapolsky([@sanapolsky](https://github.com/sanapolsky/))
